from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr25

_method_map = {
    'SetFromRule': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'SetFromRule',
        'return_type': 'bool',
    },
    'GetVersion': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetVersion',
        'return_type': 'const char *',
    },
    'TestVersion': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'TestVersion',
        'return_type': 'bool',
    },
    'TestChecksum': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'TestChecksum',
        'return_type': 'bool',
    },
    'GetSourceClass': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetSourceClass',
        'return_type': 'const char *',
    },
    'GetTargetClass': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetTargetClass',
        'return_type': 'const char *',
    },
    'GetTargetString': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetTargetString',
        'return_type': 'const char *',
    },
    'GetEmbed': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetEmbed',
        'return_type': 'bool',
    },
    'IsAliasRule': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'IsAliasRule',
        'return_type': 'bool',
    },
    'IsRenameRule': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'IsRenameRule',
        'return_type': 'bool',
    },
    'IsValid': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'IsValid',
        'return_type': 'bool',
    },
    'GetCode': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetCode',
        'return_type': 'const char *',
    },
    'GetAttributes': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetAttributes',
        'return_type': 'const char *',
    },
    'GetRuleType': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetRuleType',
        'return_type': 'ROOT::TSchemaRule::RuleType_t',
    },
    'Conflicts': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'Conflicts',
        'return_type': 'bool',
    },
    'DeclFileName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'DeclFileName',
        'return_type': 'const char *',
    },
    'ImplFileLine': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'ImplFileLine',
        'return_type': 'int',
    },
    'ImplFileName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'ImplFileName',
        'return_type': 'const char *',
    },
    'Class_Name': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'Class_Name',
        'return_type': 'const char *',
    },
    'DeclFileLine': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'DeclFileLine',
        'return_type': 'int',
    },
    'Hash': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'Hash',
        'return_type': 'unsigned long',
    },
    'ClassName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'ClassName',
        'return_type': 'const char *',
    },
    'CheckedHash': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'CheckedHash',
        'return_type': 'unsigned long',
    },
    'DistancetoPrimitive': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'DistancetoPrimitive',
        'return_type': 'int',
    },
    'GetUniqueID': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetUniqueID',
        'return_type': 'unsigned int',
    },
    'GetName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetName',
        'return_type': 'const char *',
    },
    'GetIconName': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetIconName',
        'return_type': 'const char *',
    },
    'GetObjectInfo': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetObjectInfo',
        'return_type': 'char *',
    },
    'GetTitle': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetTitle',
        'return_type': 'const char *',
    },
    'HasInconsistentHash': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'HasInconsistentHash',
        'return_type': 'bool',
    },
    'InheritsFrom': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'InheritsFrom',
        'return_type': 'bool',
    },
    'IsFolder': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'IsFolder',
        'return_type': 'bool',
    },
    'IsSortable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'IsSortable',
        'return_type': 'bool',
    },
    'IsOnHeap': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'IsOnHeap',
        'return_type': 'bool',
    },
    'IsZombie': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'IsZombie',
        'return_type': 'bool',
    },
    'Notify': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'Notify',
        'return_type': 'bool',
    },
    'Read': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'Read',
        'return_type': 'int',
    },
    'Write': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'Write',
        'return_type': 'int',
    },
    'IsDestructed': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'IsDestructed',
        'return_type': 'bool',
    },
    'TestBit': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'TestBit',
        'return_type': 'bool',
    },
    'TestBits': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'TestBits',
        'return_type': 'int',
    },
    'GetObjectStat': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::TSchemaRule',
        'method_name': 'GetObjectStat',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])


        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class TSchemaRule:
    "A class"

    class RuleType_t(Enum):
        kReadRule = 0
        kReadRawRule = 1
        kNone = 99999


    def SetFromRule(self, rule: char) -> bool:
        "A method"
        ...

    def GetVersion(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def TestVersion(self, version: int) -> bool:
        "A method"
        ...

    def TestChecksum(self, checksum: int) -> bool:
        "A method"
        ...

    def GetSourceClass(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def GetTargetClass(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def GetTargetString(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def GetEmbed(self) -> bool:
        "A method"
        ...

    def IsAliasRule(self) -> bool:
        "A method"
        ...

    def IsRenameRule(self) -> bool:
        "A method"
        ...

    def IsValid(self) -> bool:
        "A method"
        ...

    def GetCode(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def GetAttributes(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def GetRuleType(self) -> func_adl_servicex_xaodr25.ROOT.tschemarule.TSchemaRule.RuleType_t:
        "A method"
        ...

    def Conflicts(self, rule: func_adl_servicex_xaodr25.ROOT.tschemarule.TSchemaRule) -> bool:
        "A method"
        ...

    def DeclFileName(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def ImplFileLine(self) -> int:
        "A method"
        ...

    def ImplFileName(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def Class_Name(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def DeclFileLine(self) -> int:
        "A method"
        ...

    def Hash(self) -> int:
        "A method"
        ...

    def ClassName(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def CheckedHash(self) -> int:
        "A method"
        ...

    def DistancetoPrimitive(self, px: int, py: int) -> int:
        "A method"
        ...

    def GetUniqueID(self) -> int:
        "A method"
        ...

    def GetName(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def GetIconName(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def GetObjectInfo(self, px: int, py: int) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def GetTitle(self) -> func_adl_servicex_xaodr25.str.str:
        "A method"
        ...

    def HasInconsistentHash(self) -> bool:
        "A method"
        ...

    def InheritsFrom(self, classname: char) -> bool:
        "A method"
        ...

    def IsFolder(self) -> bool:
        "A method"
        ...

    def IsSortable(self) -> bool:
        "A method"
        ...

    def IsOnHeap(self) -> bool:
        "A method"
        ...

    def IsZombie(self) -> bool:
        "A method"
        ...

    def Notify(self) -> bool:
        "A method"
        ...

    def Read(self, name: char) -> int:
        "A method"
        ...

    def Write(self, name: char, option: int, bufsize: int) -> int:
        "A method"
        ...

    def IsDestructed(self) -> bool:
        "A method"
        ...

    def TestBit(self, f: int) -> bool:
        "A method"
        ...

    def TestBits(self, f: int) -> int:
        "A method"
        ...

    def GetObjectStat(self) -> bool:
        "A method"
        ...
